@@ -2,12 +2,12 @@ from django import forms
 from markitup.widgets import MarkItUpWidget
 from rest_framework.reverse import reverse_lazy
 
-from djgentelella.forms.forms import CustomForm
+from djgentelella.forms.forms import GTForm
 from djgentelella.widgets import core as genwidgets
 from . import models
 
 
-class EntryForm(CustomForm, forms.ModelForm):
+class EntryForm(GTForm, forms.ModelForm):
     class Meta:
         model = models.Entry
         exclude = ('published_content', 'author')
@@ -22,7 +22,7 @@ class EntryForm(CustomForm, forms.ModelForm):
         }
 
 
-class CategoryForm(CustomForm, forms.ModelForm):
+class CategoryForm(GTForm, forms.ModelForm):
     class Meta:
         model = models.Category
         fields = '__all__'
