@@ -2,10 +2,10 @@ from django import forms
 
 from djgentelella.models import Help
 from djgentelella.widgets import core as genwidgets
-from .forms import CustomForm
+from .forms import GTForm
 
 
-class HelpForm(CustomForm, forms.ModelForm):
+class HelpForm(GTForm, forms.ModelForm):
     class Meta:
         model = Help
         fields = ['help_title', 'help_text']
