@@ -23,9 +23,8 @@ DATATABLES_SUPPORT_LANGUAGES = getattr(settings, 'DATATABLES_SUPPORT_LANGUAGES',
 DEFAULT_GROUP_MODEL_BASE = 'GT_GROUP_MODEL'
 
 DEFAULT_USER_MODEL_BASE = 'GT_USER_MODEL'
-
+REGISTER_DEFAULT_USER_API = getattr(settings, 'REGISTER_DEFAULT_USER_API', True)
 DEFAULT_GROUP_MODEL = 'django.contrib.auth.models.Group'
-
 DEFAULT_USER_MODEL = 'django.contrib.auth.models.User'
 
 GROUP_MODEL_BASE = getattr(
@@ -43,7 +42,7 @@ try:
 except Exception as e:
     from django.contrib.auth.models import User
 
-#####################################################
+############################################
 #    Chunked Upload
 ############################################
 
@@ -84,5 +83,7 @@ CONTENT_TYPE = getattr(settings, 'CHUNKED_UPLOAD_CONTENT_TYPE',
 DEFAULT_MAX_BYTES = None
 MAX_BYTES = getattr(settings, 'CHUNKED_UPLOAD_MAX_BYTES', DEFAULT_MAX_BYTES)
 
-#############################################################
+############################################
 #   END UPLOAD CHUNKED
+
+
