@@ -27,4 +27,18 @@ function showHideRelatedFormFields(instance){
         });
         instance.trigger('change');
     }
-}
\ No newline at end of file
+    var relh = instance.data('relhidden');
+    if(relh != undefined ){
+        var relateditemsh = create_identifiers(relh.split(';'));
+        instance.on('change', function(e){
+            for(var x=0; x<relateditemsh.length; x++){
+                if(this.checked){
+                    $(relateditemsh[x]).closest(parentclass).hide();
+                }else{
+                    $(relateditemsh[x]).closest(parentclass).show();
+                }
+            }
+        });
+         instance.trigger('change');
+    }
+}
