@@ -31,6 +31,16 @@ function formatDataTableParams(dataTableParams, settings){
 }
 
 var default_table_columns_display = {}
+function toggle_select_all(e){
+    let tinstance = $(e.target);
+    if(tinstance[0].checked){
+        tinstance.closest('table').find('.gtcheckable').prop('checked', true);
+        tinstance.closest('table').find('.checkableall').prop('checked', true);
+    }else{
+        tinstance.closest('table').find('.gtcheckable').prop('checked', false);
+        tinstance.closest('table').find('.checkableall').prop('checked', false);
+    }
+}
 function addSearchInputsAndFooterDataTable(dataTable, tableId, columns) {
     // takes care of adding the search inputs to each of the columns of the datatable, it will
     // hide/display them according to how the table changes in the responsive mode
@@ -45,7 +55,7 @@ function addSearchInputsAndFooterDataTable(dataTable, tableId, columns) {
     if($(tableId + ' thead tr').length < 2){  // clone the tr only if it wasn't cloned before
        $(tableId + ' thead tr').clone(false).appendTo(tableId + ' thead');
     }
-
+    let checkable_count=0;
     $(tableId + ' thead tr:eq(1) th').each(function (i) { // add search fields if they are not there already and the column is visible
         var currentColumn = dataTable.column(i);
         var is_display = true
@@ -54,7 +64,7 @@ function addSearchInputsAndFooterDataTable(dataTable, tableId, columns) {
         }
         var columnType = dataTable.settings()[0].aoColumns[i].type; // get the field type
         //currentColumn.responsiveHidden()
-        if (is_display && currentColumn.visible() && columnType !== 'actions') {  // column is visible
+        if (is_display && currentColumn.visible() && columnType !== 'actions' ) {  // column is visible
             $(this).css('display', ''); // when it was cloned it might have had display:none specified
             if($(this).find('input').length === 0 && $(this).find('select').length === 0) {  // add the input/select just if it doesn't exist already
                 var title = currentColumn.header().textContent;  // get the field name
@@ -127,10 +137,24 @@ function addSearchInputsAndFooterDataTable(dataTable, tableId, columns) {
             $(this).css('display', 'none');
         }
 
+        if(columnType === 'checkable'){
+             $(this).html("");
+             checkable_count=1;
+             if($(dataTable.context[0].nTable).data()['checkable']==undefined){
+                 $(dataTable.context[0].nTable).find('.checkableall').click(toggle_select_all);
+                 $(dataTable.context[0].nTable).data()['checkable']=true;
+             }
+        }
+
+
     });
     // add the footer to the table according to the current header - delete previous one before
     $(tableId).find('tfoot').remove();
     $(tableId).append($('<tfoot/>').append( $(tableId + " thead tr:eq(0)").clone()));
+    if(checkable_count>0){
+        $(tableId).children().last().find('.checkableall').click(toggle_select_all);
+        $(tableId).children().last().find('.checkableall').prop('width', 'unset');
+    }
 }
 
 function clearDataTableFilters(dataTable, tableId){
@@ -138,7 +162,7 @@ function clearDataTableFilters(dataTable, tableId){
     $(tableId).find('input, select').val('');
     $(tableId).find('.tableselect').val(null).trigger('change');
 }
-function yesnoprint(data, type, row, meta){ return data ? "<i class=\"fa fa-check-circle\"></i> "+gettext("Yes") : "<i class=\"fa fa-times-circle\"></i>"+gettext("No"); };
+function yesnoprint(data, type, row, meta){ return data ? "<i class=\"fa fa-check-circle\"></i> "+gettext("Yes") : "<i class=\"fa fa-times-circle\"></i> "+gettext("No"); };
 function emptyprint(data, type, row, meta){ return data ? data : "--"; };
 // hacer que se pueda definir el tipo el objeto ej data.name
 
@@ -181,12 +205,12 @@ function objshowlink(data, type, row, meta){ return data ? '<a href="'+data.url+
 function objnode(data, type, row, meta){ return data ? '<'+data.tagName+' href="'+data.url+'" '+data.extraattr+' class="'+(data.class!=undefined ? data.class : 'link')+'"> '+data.display_name+ '</'+data.tagName+'>': ''; };
 function objShowBool(data, type, row, meta){ return data ? '<i class="fa fa-check-circle" title="' + data + '">': '<i class="fa fa-times-circle" title="' +  data + '">'; };
 
-document.table_default_dom = "<'row mb-3'<'col-sm-12 col-md-12 mb-1 d-flex align-items-center justify-content-center'f>" +
-                 "<'col-sm-6 col-md-6 mt-1 d-flex align-items-center justify-content-start'B>" +
-                 "<'col-sm-6 col-md-6 mt-1 d-flex align-items-center 'l>>" +
+document.table_default_dom = "<'row mb-1'<'col-sm-4 col-md-4 d-flex align-items-center justify-content-start'f>" +
+                 "<'col-sm-4 col-md-4 d-flex align-items-center justify-content-center'B>" +
+                 "<'col-sm-3 col-md-3 d-flex align-items-center justify-content-end 'l>>" +
                  "<'row'<'col-sm-12'tr>><'row'<'col-sm-12 col-md-5'i><'col-sm-12 col-md-7'p>>";
 
-
+$.fn.dataTable.Buttons.defaults.dom.button.className="btn btn-sm";
 
 function gtCreateDataTable(id, url, table_options={}){
     const options = Object.assign({}, {
@@ -215,7 +239,7 @@ function gtCreateDataTable(id, url, table_options={}){
                 action: function ( e, dt, node, config ) {clearDataTableFilters(dt, id)},
                 text: '<i class="fa fa-eraser" aria-hidden="true"></i>',
                 titleAttr: gettext('Clear Filters'),
-                className: 'btn-sm mr-4'
+                className: 'btn-outline-secondary mr-4'
             },
         ],
         ajax: {
@@ -245,8 +269,23 @@ function gtCreateDataTable(id, url, table_options={}){
 
 function createDataTable(id, url, extraoptions={}, addfilter=false, formatDataTableParamsfnc=formatDataTableParams){
     const options = Object.assign({}, {
-       formatDataTableParamsfnc : formatDataTableParams,
+       formatDataTableParamsfnc : formatDataTableParamsfnc,
        addfilter: addfilter
     }, extraoptions);
     return gtCreateDataTable(id, url, options);
 }
+
+function truncateTextRenderer(maxChars = 100) {
+    return (data, type, row, meta)=> {
+        if (type === 'display' && typeof data === 'string') {
+            const text = data.trim();
+            if (text.length > maxChars) {
+                return `<span title="${text.replace(/"/g, '&quot;')}" style="display:inline; line-height:1; margin:0; padding:0;">${text.substring(0, maxChars)}...</span>`;
+            }
+            return text
+        }
+
+        return data;
+    };
+}
+
