@@ -1,3 +1,5 @@
+import json
+
 from django.forms import (
     PasswordInput as DJPasswordInput,
     FileInput as DJFileInput,
@@ -178,7 +180,7 @@ class FileInput(DJFileInput):
             attrs = update_kwargs(
                 attrs,
                 self.__class__.__name__,
-                base_class='djgentelella-file-inputt form-control')
+                base_class='djgentelella-file-input form-control')
         if 'data-href' not in attrs:
             attrs.update({'data-href': reverse_lazy('upload_file_view')})
         if 'data-done' not in attrs:
@@ -192,10 +194,12 @@ class FileInput(DJFileInput):
     def value_from_datadict(self, data, files, name):
         dev = None
         token = data.get(name)
-        tmpupload = ChunkedUpload.objects.filter(upload_id=token).first()
-        if tmpupload:
-            dev = tmpupload.get_uploaded_file()
-            tmpupload.delete()
+        if token:
+            load_token = json.loads(token)
+            tmpupload = ChunkedUpload.objects.filter(upload_id=load_token['token']).first()
+            if tmpupload:
+                dev = tmpupload.get_uploaded_file()
+                tmpupload.delete()
         return dev
 
     def value_omitted_from_data(self, data, files, name):
